#
# spec file for package jitterentropy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global _lto_cflags %{?_lto_cflags} -ffat-lto-objects

Name:           jitterentropy
Summary:        A userspace library for jitter entropy generation
License:        BSD-3-Clause OR GPL-2.0-or-later
Group:          Development/Tools/Other
Version:        3.4.1
Release:        3.2
URL:            https://github.com/smuellerDD/jitterentropy-library
Source0:        https://github.com/smuellerDD/jitterentropy-library/archive/refs/tags/v%{version}.tar.gz
Source1:        baselibs.conf
#PATCH-FIX-UPSTREAM github.com/smuellerDD/jitterentropy-library/commit/7bf9f85
Patch0:         jitterentropy-fix-a-stack-corruption-on-s390x.patch

%description
The Jitter RNG provides a noise source using the CPU execution
timing jitter. It depends on a high-resolution time stamp.

The design of this RNG is given in the documentation found at
http://www.chronox.de/jent.html . This documentation also covers the full
assessment of the SP800-90B compliance as well as all required test code.

%package -n libjitterentropy3
Summary:        Jitter entropy generator shared library
Group:          System/Libraries

%description -n libjitterentropy3
The Jitter RNG provides a noise source using the CPU execution
timing jitter. It depends on a high-resolution time stamp.

This package contains the shared library.

%package devel
Summary:        Jitter entropy generator development header and library
Group:          Development/Tools/Other
Requires:       libjitterentropy3 = %{version}

%description devel
The Jitter RNG provides a noise source using the CPU execution
timing jitter. It depends on a high-resolution time stamp.

This package contains the development header and library.

%package devel-static
Summary:        Jitter entropy generator static library
Group:          Development/Tools/Other

%description devel-static
The Jitter RNG provides a noise source using the CPU execution
timing jitter. It depends on a high-resolution time stamp.

This package contains the static library.

%prep
%autosetup -n jitterentropy-library-%version

%build
%set_build_flags
%make_build PREFIX="%_prefix" LIBDIR="%_lib"

%install
%make_install PREFIX="%_prefix" LIBDIR="%_lib" all install-static

%post -n libjitterentropy3 -p /sbin/ldconfig
%postun -n libjitterentropy3 -p /sbin/ldconfig

%files devel
%license LICENSE.gplv2 LICENSE LICENSE.bsd
%_includedir/jitterentropy-base-user.h
%_includedir/jitterentropy.h
%_libdir/libjitterentropy.so
%_mandir/man3/jitterentropy.3*

%files devel-static
%license LICENSE.gplv2 LICENSE LICENSE.bsd
%_libdir/libjitterentropy.a

%files -n libjitterentropy3
%license LICENSE.gplv2 LICENSE LICENSE.bsd
%_libdir/libjitterentropy.so.3
%_libdir/libjitterentropy.so.%version

%changelog
* Wed Dec  6 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Make use of distro flags with %%set_build_flags
* Wed Mar 22 2023 Pedro Monreal <pmonreal@suse.com>
- Fix a stack corruption on s390x: [bsc#1209627]
  * Output size of the STCKE command on s390x is 16 bytes, compared
    to 8 bytes of the STCK command. Fix a stack corruption in the
    s390x version of jent_get_nstime(). Add some more detailed
    information on the STCKE command.
  * github.com/smuellerDD/jitterentropy-library/commit/7bf9f85
  * Add jitterentropy-fix-a-stack-corruption-on-s390x.patch
* Mon Sep 12 2022 Marcus Meissner <meissner@suse.com>
- updated to 3.4.1
  * add FIPS 140 hints to man page
  * simplify the test tool to search for optimal configurations
  * fix: jent_loop_shuffle: re-add setting the time that was lost with 3.4.0
  * enhancement: add ARM64 assembler code to read high-res timer
* Wed Aug  3 2022 Marcus Meissner <meissner@suse.com>
- updated to 3.4.0
  * enhancement: add API call jent_set_fips_failure_callback as requested by Daniel Ojalvo
  * fix: Change the SHA-3 integration: The entropy pool is now a SHA-3 state.
  It is filled with the time delta containing entropy and auxiliary data that does not contain entropy using a SHA update operation. The auxiliary data is calculated by a SHA-3 hashing of some varying state data. The time delta that contains entropy is measured about the SHA-3 hasing of the auxiliary data. This satisfies FIPS 140-3 IG D.K resolutions 4, 6, and 8.
  * enhancement: add CMake support by Andrew Hopkins
- updated to 3.3.1
  * fix: bug fix in initialization logic by Vladis Dronov <vdronov@redhat.com>
  * fix: use __asm__ instead of asm to suit the C11 standard
- added a -devel-static package to be able to link it static.
* Tue Sep 28 2021 Jan Engelhardt <jengelh@inai.de>
- Trim conjecture from descriptions.
* Tue Sep 21 2021 Marcus Meissner <meissner@suse.com>
- add a userspace jitter entropy generator library
